@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "6kbbs" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-10-29
+Plugin.define do
+name "6kbbs"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-10-29
+]
 version "0.1"
 description "6kbbs - Forum"
 website "http://www.6kbbs.net/"
