@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "AEF" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-09-27
+Plugin.define do
+name "AEF"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-09-27
+]
 version "0.1"
 description "Advanced Electron Forum (AEF) - bulletin board software - requires PHP and MySQL"
 website "http://www.anelectron.com/"
