@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "AJA-Video-Converter" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-12-05
+Plugin.define do
+name "AJA-Video-Converter"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-12-05
+]
 version "0.1"
 description "AJA digital video converter devices"
 website "http://www.aja.com/en/products/convert/"
