@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "BoonEx-Dolphin" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-11-20
+Plugin.define do
+name "BoonEx-Dolphin"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-11-20
+]
 version "0.1"
 description "BoonEx Dolphin - open-source, downloadable, scalable, customizable, full-featured, independent and free software package for building social networks, dating sites and niche communities."
 website "http://www.boonex.com/dolphin"
