@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-01-08 #
-# Updated version detection method
-##
-Plugin.define "BosClassifieds" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-22
+Plugin.define do
+name "BosClassifieds"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-22
+  # v0.2 # 2011-01-08 # Updated version detection method. 
+]
 version "0.2"
 description "The BosClassifieds Classified Ad System will allow your web site visitors to place their own classified ads to your web site into categories which you specify. All BosDev, Inc products require a web server running PHP version 4.10 or higher, MySQL 3.23 or higher, and the GD2 graphics library."
 website "http://www.bosdev.com/bosclassifieds/"
