@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "McAfee-ePolicy-Orchestrator" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-06-22
+Plugin.define do
+name "McAfee-ePolicy-Orchestrator"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-06-22
+]
 version "0.1"
 description "McAfee ePolicy Orchestrator (ePO) - unified security management"
 website "http://www.mcafee.com/us/products/epolicy-orchestrator.aspx"
