@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "TeamSpeak-Server-Log" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-10-15
+Plugin.define do
+name "TeamSpeak-Server-Log"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-10-15
+]
 version "0.1"
 description "This plugin extracts the username and password from TeamSpeak server.log files."
 
@@ -20,7 +23,7 @@ matches [
 ]
 
 # Extract passwords
-def passive
+passive do
 	m=[]
 
 	if @body =~ /-------------- log started at /
