@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Tengine-Web-Server" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-05-17
+Plugin.define do
+name "Tengine-Web-Server"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-05-17
+]
 version "0.1"
 description "Tengine is a web server originated by Taobao, the largest e-commerce website in Asia. It is based on the popular Nginx HTTP server."
 website "http://tengine.taobao.org/"
